Documentation
¶
Index ¶
Constants ¶
const ( RoleAttendee = 0 RolePublisher = 1 RoleSubscriber = 2 RoleAdmin = 101 )
Role consts
Variables ¶
This section is empty.
Functions ¶
func BuildTokenWithUID ¶
func BuildTokenWithUID(appID string, appCertificate string, channelName string, uid uint32, role Role, privilegeExpiredTs uint32) (string, error)
BuildTokenWithUID @param appID: The App ID issued to you by Agora. Apply for a new App ID from Agora Dashboard if it is missing from your kit. See Get an App ID. @param appCertificate: Certificate of the application that you registered in the Agora Dashboard. See Get an App Certificate. @param channelName:Unique channel name for the AgoraRTC session in the string format @param uid: User ID. A 32-bit unsigned integer with a value ranging from 1 to (2^32-1). uid must be unique. @param role: Role_Publisher = 1: A broadcaster (host) in a live-broadcast profile. Role_Subscriber = 2: (Default) A audience in a live-broadcast profile. @param privilegeExpireTs: represented by the number of seconds elapsed since 1/1/1970. If, for example, you want to access the Agora Service within 10 minutes after the token is generated, set expireTimestamp as the current timestamp + 600 (seconds)
func BuildTokenWithUserAccount ¶
func BuildTokenWithUserAccount(appID string, appCertificate string, channelName string, userAccount string, role Role, privilegeExpiredTs uint32) (string, error)
BuildTokenWithUserAccount @param appID: The App ID issued to you by Agora. Apply for a new App ID from Agora Dashboard if it is missing from your kit. See Get an App ID. @param appCertificate: Certificate of the application that you registered in the Agora Dashboard. See Get an App Certificate. @param channelName:Unique channel name for the AgoraRTC session in the string format @param userAccount: The user account. @param role: Role_Publisher = 1: A broadcaster (host) in a live-broadcast profile. Role_Subscriber = 2: (Default) A audience in a live-broadcast profile. @param privilegeExpireTs: represented by the number of seconds elapsed since 1/1/1970. If, for example, you want to access the Agora Service within 10 minutes after the token is generated, set expireTimestamp as the current timestamp + 600 (seconds)